pub struct SurfpoolAccountsDataRpc;Trait Implementations
Sourceimpl AccountsData for SurfpoolAccountsDataRpc
impl AccountsData for SurfpoolAccountsDataRpc
type Metadata = Option<RunloopContext>
Sourcefn get_account_info(
&self,
meta: Self::Metadata,
pubkey_str: String,
config: Option<RpcAccountInfoConfig>,
) -> BoxFuture<Result<RpcResponse<Option<UiAccount>>>>
fn get_account_info( &self, meta: Self::Metadata, pubkey_str: String, config: Option<RpcAccountInfoConfig>, ) -> BoxFuture<Result<RpcResponse<Option<UiAccount>>>>
Returns detailed information about an account given its public key. Read more
Sourcefn get_multiple_accounts(
&self,
meta: Self::Metadata,
pubkeys_str: Vec<String>,
config: Option<RpcAccountInfoConfig>,
) -> BoxFuture<Result<RpcResponse<Vec<Option<UiAccount>>>>>
fn get_multiple_accounts( &self, meta: Self::Metadata, pubkeys_str: Vec<String>, config: Option<RpcAccountInfoConfig>, ) -> BoxFuture<Result<RpcResponse<Vec<Option<UiAccount>>>>>
Returns account information for multiple public keys in a single call. Read more
Sourcefn get_block_commitment(
&self,
_meta: Self::Metadata,
_block: Slot,
) -> Result<RpcBlockCommitment<BlockCommitmentArray>>
fn get_block_commitment( &self, _meta: Self::Metadata, _block: Slot, ) -> Result<RpcBlockCommitment<BlockCommitmentArray>>
Returns commitment levels for a given block (slot). Read more
Sourcefn get_token_account_balance(
&self,
meta: Self::Metadata,
pubkey_str: String,
commitment: Option<CommitmentConfig>,
) -> BoxFuture<Result<RpcResponse<Option<UiTokenAmount>>>>
fn get_token_account_balance( &self, meta: Self::Metadata, pubkey_str: String, commitment: Option<CommitmentConfig>, ) -> BoxFuture<Result<RpcResponse<Option<UiTokenAmount>>>>
Returns the balance of a token account, given its public key. Read more
Sourcefn get_token_supply(
&self,
_meta: Self::Metadata,
_mint_str: String,
_commitment: Option<CommitmentConfig>,
) -> Result<RpcResponse<UiTokenAmount>>
fn get_token_supply( &self, _meta: Self::Metadata, _mint_str: String, _commitment: Option<CommitmentConfig>, ) -> Result<RpcResponse<UiTokenAmount>>
Returns the total supply of a token, given its mint address. Read more
Sourcefn to_delegate(self) -> IoDelegate<Self, Self::Metadata>
fn to_delegate(self) -> IoDelegate<Self, Self::Metadata>
Create an
IoDelegate, wiring rpc calls to the trait methods.Sourceimpl Clone for SurfpoolAccountsDataRpc
impl Clone for SurfpoolAccountsDataRpc
Sourcefn clone(&self) -> SurfpoolAccountsDataRpc
fn clone(&self) -> SurfpoolAccountsDataRpc
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for SurfpoolAccountsDataRpc
impl RefUnwindSafe for SurfpoolAccountsDataRpc
impl Send for SurfpoolAccountsDataRpc
impl Sync for SurfpoolAccountsDataRpc
impl Unpin for SurfpoolAccountsDataRpc
impl UnwindSafe for SurfpoolAccountsDataRpc