pub struct SurfpoolAdminRpc;Trait Implementations
Sourceimpl AdminRpc for SurfpoolAdminRpc
impl AdminRpc for SurfpoolAdminRpc
type Metadata = Option<RunloopContext>
Sourcefn exit(&self, meta: Self::Metadata) -> Result<()>
fn exit(&self, meta: Self::Metadata) -> Result<()>
Immediately shuts down the RPC server. Read more
fn reload_plugin( &self, _meta: Self::Metadata, _name: String, _config_file: String, ) -> BoxFuture<Result<()>>
Sourcefn unload_plugin(
&self,
_meta: Self::Metadata,
_name: String,
) -> BoxFuture<Result<()>>
fn unload_plugin( &self, _meta: Self::Metadata, _name: String, ) -> BoxFuture<Result<()>>
Reloads a runtime plugin with new configuration. Read more
Sourcefn load_plugin(
&self,
meta: Self::Metadata,
config_file: String,
) -> BoxFuture<Result<String>>
fn load_plugin( &self, meta: Self::Metadata, config_file: String, ) -> BoxFuture<Result<String>>
Dynamically loads a new plugin into the runtime from a configuration file. Read more
Sourcefn list_plugins(&self, _meta: Self::Metadata) -> BoxFuture<Result<Vec<String>>>
fn list_plugins(&self, _meta: Self::Metadata) -> BoxFuture<Result<Vec<String>>>
Returns a list of all currently loaded plugin names. Read more
Sourcefn rpc_addr(&self, _meta: Self::Metadata) -> Result<Option<SocketAddr>>
fn rpc_addr(&self, _meta: Self::Metadata) -> Result<Option<SocketAddr>>
Returns the address of the RPC server. Read more
Sourcefn set_log_filter(&self, _filter: String) -> Result<()>
fn set_log_filter(&self, _filter: String) -> Result<()>
Sets a filter for log messages in the system. Read more
Sourcefn start_time(&self, _meta: Self::Metadata) -> Result<SystemTime>
fn start_time(&self, _meta: Self::Metadata) -> Result<SystemTime>
Returns the system start time. Read more
Adds an authorized voter to the system. Read more
Adds an authorized voter to the system using a byte-encoded keypair. Read more
Removes all authorized voters from the system. Read more
Sourcefn set_identity(
&self,
_meta: Self::Metadata,
_keypair_file: String,
_require_tower: bool,
) -> Result<()>
fn set_identity( &self, _meta: Self::Metadata, _keypair_file: String, _require_tower: bool, ) -> Result<()>
Sets the identity for the system using the provided keypair. Read more
Sourcefn set_identity_from_bytes(
&self,
_meta: Self::Metadata,
_identity_keypair: Vec<u8>,
_require_tower: bool,
) -> Result<()>
fn set_identity_from_bytes( &self, _meta: Self::Metadata, _identity_keypair: Vec<u8>, _require_tower: bool, ) -> Result<()>
Sets the identity for the system using a keypair provided as a byte array. Read more
Sourcefn set_staked_nodes_overrides(
&self,
_meta: Self::Metadata,
_path: String,
) -> Result<()>
fn set_staked_nodes_overrides( &self, _meta: Self::Metadata, _path: String, ) -> Result<()>
Sets the overrides for staked nodes using a specified path. Read more
Sourcefn repair_shred_from_peer(
&self,
_meta: Self::Metadata,
_pubkey: Option<Pubkey>,
_slot: u64,
_shred_index: u64,
) -> Result<()>
fn repair_shred_from_peer( &self, _meta: Self::Metadata, _pubkey: Option<Pubkey>, _slot: u64, _shred_index: u64, ) -> Result<()>
Repairs a shred from a peer node in the network. Read more
Sourcefn set_repair_whitelist(
&self,
_meta: Self::Metadata,
_whitelist: Vec<Pubkey>,
) -> Result<()>
fn set_repair_whitelist( &self, _meta: Self::Metadata, _whitelist: Vec<Pubkey>, ) -> Result<()>
Sets the whitelist of nodes allowed to repair shreds. Read more
Sourcefn get_secondary_index_key_size(
&self,
_meta: Self::Metadata,
_pubkey_str: String,
) -> Result<HashMap<RpcAccountIndex, usize>>
fn get_secondary_index_key_size( &self, _meta: Self::Metadata, _pubkey_str: String, ) -> Result<HashMap<RpcAccountIndex, usize>>
Retrieves the size of the secondary index key for a given account. Read more
Sourcefn set_public_tpu_address(
&self,
_meta: Self::Metadata,
_public_tpu_addr: SocketAddr,
) -> Result<()>
fn set_public_tpu_address( &self, _meta: Self::Metadata, _public_tpu_addr: SocketAddr, ) -> Result<()>
Sets the public TPU (Transaction Processing Unit) address. Read more
Sourcefn set_public_tpu_forwards_address(
&self,
_meta: Self::Metadata,
_public_tpu_forwards_addr: SocketAddr,
) -> Result<()>
fn set_public_tpu_forwards_address( &self, _meta: Self::Metadata, _public_tpu_forwards_addr: SocketAddr, ) -> Result<()>
Sets the public TPU forwards address. Read more
Sourcefn to_delegate(self) -> IoDelegate<Self, Self::Metadata>
fn to_delegate(self) -> IoDelegate<Self, Self::Metadata>
Create an
IoDelegate, wiring rpc calls to the trait methods.Auto Trait Implementations
impl Freeze for SurfpoolAdminRpc
impl RefUnwindSafe for SurfpoolAdminRpc
impl Send for SurfpoolAdminRpc
impl Sync for SurfpoolAdminRpc
impl Unpin for SurfpoolAdminRpc
impl UnwindSafe for SurfpoolAdminRpc