pub struct SurfpoolBankDataRpc;Trait Implementations
Sourceimpl BankData for SurfpoolBankDataRpc
impl BankData for SurfpoolBankDataRpc
type Metadata = Option<RunloopContext>
Sourcefn get_minimum_balance_for_rent_exemption(
&self,
meta: Self::Metadata,
data_len: usize,
_commitment: Option<CommitmentConfig>,
) -> Result<u64>
fn get_minimum_balance_for_rent_exemption( &self, meta: Self::Metadata, data_len: usize, _commitment: Option<CommitmentConfig>, ) -> Result<u64>
Returns the minimum balance required for rent exemption based on the given data length. Read more
Sourcefn get_inflation_governor(
&self,
_meta: Self::Metadata,
_commitment: Option<CommitmentConfig>,
) -> Result<RpcInflationGovernor>
fn get_inflation_governor( &self, _meta: Self::Metadata, _commitment: Option<CommitmentConfig>, ) -> Result<RpcInflationGovernor>
Retrieves the inflation governor settings for the network. Read more
Sourcefn get_inflation_rate(&self, _meta: Self::Metadata) -> Result<RpcInflationRate>
fn get_inflation_rate(&self, _meta: Self::Metadata) -> Result<RpcInflationRate>
Retrieves the current inflation rate for the network. Read more
Sourcefn get_epoch_schedule(&self, _meta: Self::Metadata) -> Result<EpochSchedule>
fn get_epoch_schedule(&self, _meta: Self::Metadata) -> Result<EpochSchedule>
Retrieves the epoch schedule for the network. Read more
Sourcefn get_slot_leader(
&self,
_meta: Self::Metadata,
_config: Option<RpcContextConfig>,
) -> Result<String>
fn get_slot_leader( &self, _meta: Self::Metadata, _config: Option<RpcContextConfig>, ) -> Result<String>
Retrieves the leader of the current slot. Read more
Sourcefn get_slot_leaders(
&self,
_meta: Self::Metadata,
_start_slot: Slot,
_limit: u64,
) -> Result<Vec<String>>
fn get_slot_leaders( &self, _meta: Self::Metadata, _start_slot: Slot, _limit: u64, ) -> Result<Vec<String>>
Retrieves the leaders for a specified range of slots. Read more
Sourcefn get_block_production(
&self,
_meta: Self::Metadata,
_config: Option<RpcBlockProductionConfig>,
) -> Result<RpcResponse<RpcBlockProduction>>
fn get_block_production( &self, _meta: Self::Metadata, _config: Option<RpcBlockProductionConfig>, ) -> Result<RpcResponse<RpcBlockProduction>>
Retrieves block production information for the specified validator identity or range of slots. Read more
Sourcefn to_delegate(self) -> IoDelegate<Self, Self::Metadata>
fn to_delegate(self) -> IoDelegate<Self, Self::Metadata>
Create an
IoDelegate, wiring rpc calls to the trait methods.Auto Trait Implementations
impl Freeze for SurfpoolBankDataRpc
impl RefUnwindSafe for SurfpoolBankDataRpc
impl Send for SurfpoolBankDataRpc
impl Sync for SurfpoolBankDataRpc
impl Unpin for SurfpoolBankDataRpc
impl UnwindSafe for SurfpoolBankDataRpc