pub struct SurfnetCheatcodesRpc;Trait Implementations
Sourceimpl Clone for SurfnetCheatcodesRpc
impl Clone for SurfnetCheatcodesRpc
Sourcefn clone(&self) -> SurfnetCheatcodesRpc
fn clone(&self) -> SurfnetCheatcodesRpc
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SurfnetCheatcodes for SurfnetCheatcodesRpc
impl SurfnetCheatcodes for SurfnetCheatcodesRpc
Sourcefn clone_program_account(
&self,
meta: Self::Metadata,
source_program_id: String,
destination_program_id: String,
) -> BoxFuture<Result<RpcResponse<()>>>
fn clone_program_account( &self, meta: Self::Metadata, source_program_id: String, destination_program_id: String, ) -> BoxFuture<Result<RpcResponse<()>>>
Clones a program account from one program ID to another. A program account contains a pointer to a program data account, which is a PDA derived from the program ID. So, when cloning a program account, we need to clone the program data account as well.
This method will:
- Get the program account for the source program ID.
- Get the program data account for the source program ID.
- Calculate the program data address for the destination program ID.
- Set the destination program account’s data to point to the calculated destination program address.
- Copy the source program data account to the destination program data account.
type Metadata = Option<RunloopContext>
Sourcefn set_account(
&self,
meta: Self::Metadata,
pubkey_str: String,
update: AccountUpdate,
) -> BoxFuture<Result<RpcResponse<()>>>
fn set_account( &self, meta: Self::Metadata, pubkey_str: String, update: AccountUpdate, ) -> BoxFuture<Result<RpcResponse<()>>>
A “cheat code” method for developers to set or update an account in Surfpool. Read more
Sourcefn set_token_account(
&self,
meta: Self::Metadata,
owner_str: String,
mint_str: String,
update: TokenAccountUpdate,
some_token_program_str: Option<String>,
) -> BoxFuture<Result<RpcResponse<()>>>
fn set_token_account( &self, meta: Self::Metadata, owner_str: String, mint_str: String, update: TokenAccountUpdate, some_token_program_str: Option<String>, ) -> BoxFuture<Result<RpcResponse<()>>>
A “cheat code” method for developers to set or update a token account in Surfpool. Read more
Sourcefn profile_transaction(
&self,
meta: Self::Metadata,
transaction_data_b64: String,
tag: Option<String>,
config: Option<RpcProfileResultConfig>,
) -> BoxFuture<Result<RpcResponse<UiKeyedProfileResult>>>
fn profile_transaction( &self, meta: Self::Metadata, transaction_data_b64: String, tag: Option<String>, config: Option<RpcProfileResultConfig>, ) -> BoxFuture<Result<RpcResponse<UiKeyedProfileResult>>>
Estimates the compute units that a given transaction will consume. Read more
Sourcefn get_profile_results_by_tag(
&self,
meta: Self::Metadata,
tag: String,
config: Option<RpcProfileResultConfig>,
) -> Result<RpcResponse<Option<Vec<UiKeyedProfileResult>>>>
fn get_profile_results_by_tag( &self, meta: Self::Metadata, tag: String, config: Option<RpcProfileResultConfig>, ) -> Result<RpcResponse<Option<Vec<UiKeyedProfileResult>>>>
Retrieves all profiling results for a given tag. Read more
Sourcefn set_supply(
&self,
meta: Self::Metadata,
update: SupplyUpdate,
) -> BoxFuture<Result<RpcResponse<()>>>
fn set_supply( &self, meta: Self::Metadata, update: SupplyUpdate, ) -> BoxFuture<Result<RpcResponse<()>>>
A “cheat code” method for developers to set or update the network supply information in Surfpool. Read more
A cheat code to set the upgrade authority of a program’s ProgramData account. Read more
Sourcefn get_transaction_profile(
&self,
meta: Self::Metadata,
signature_or_uuid: UuidOrSignature,
config: Option<RpcProfileResultConfig>,
) -> Result<RpcResponse<Option<UiKeyedProfileResult>>>
fn get_transaction_profile( &self, meta: Self::Metadata, signature_or_uuid: UuidOrSignature, config: Option<RpcProfileResultConfig>, ) -> Result<RpcResponse<Option<UiKeyedProfileResult>>>
A cheat code to get the transaction profile for a given signature or UUID. Read more
Sourcefn register_idl(
&self,
meta: Self::Metadata,
idl: Idl,
slot: Option<Slot>,
) -> Result<RpcResponse<()>>
fn register_idl( &self, meta: Self::Metadata, idl: Idl, slot: Option<Slot>, ) -> Result<RpcResponse<()>>
A cheat code to register an IDL for a given program in memory. Read more
Sourcefn get_idl(
&self,
meta: Self::Metadata,
program_id: String,
slot: Option<Slot>,
) -> Result<RpcResponse<Option<Idl>>>
fn get_idl( &self, meta: Self::Metadata, program_id: String, slot: Option<Slot>, ) -> Result<RpcResponse<Option<Idl>>>
A cheat code to get the registered IDL for a given program ID. Read more
Sourcefn get_local_signatures(
&self,
meta: Self::Metadata,
limit: Option<u64>,
) -> BoxFuture<Result<RpcResponse<Vec<RpcLogsResponse>>>>
fn get_local_signatures( &self, meta: Self::Metadata, limit: Option<u64>, ) -> BoxFuture<Result<RpcResponse<Vec<RpcLogsResponse>>>>
A cheat code to get the last 50 local signatures from the local network. Read more
Sourcefn pause_clock(&self, meta: Self::Metadata) -> Result<EpochInfo>
fn pause_clock(&self, meta: Self::Metadata) -> Result<EpochInfo>
A cheat code to freeze the Surfnet clock on the local network.
All time progression halts until resumed. Read more
Sourcefn resume_clock(&self, meta: Self::Metadata) -> Result<EpochInfo>
fn resume_clock(&self, meta: Self::Metadata) -> Result<EpochInfo>
A cheat code to resume Solana clock progression after it was paused.
The validator will start producing new slots again. Read more
Sourcefn time_travel(
&self,
meta: Self::Metadata,
config: Option<TimeTravelConfig>,
) -> Result<EpochInfo>
fn time_travel( &self, meta: Self::Metadata, config: Option<TimeTravelConfig>, ) -> Result<EpochInfo>
A cheat code to jump forward or backward in time on the local network.
Useful for testing epoch-based or time-sensitive logic. Read more
Sourcefn reset_account(
&self,
meta: Self::Metadata,
pubkey: String,
config: Option<ResetAccountConfig>,
) -> Result<RpcResponse<()>>
fn reset_account( &self, meta: Self::Metadata, pubkey: String, config: Option<ResetAccountConfig>, ) -> Result<RpcResponse<()>>
A cheat code to reset an account on the local network. Read more
Sourcefn reset_network(
&self,
meta: Self::Metadata,
) -> BoxFuture<Result<RpcResponse<()>>>
fn reset_network( &self, meta: Self::Metadata, ) -> BoxFuture<Result<RpcResponse<()>>>
A cheat code to reset a network. Read more
Sourcefn stream_account(
&self,
meta: Self::Metadata,
pubkey_str: String,
config: Option<StreamAccountConfig>,
) -> Result<RpcResponse<()>>
fn stream_account( &self, meta: Self::Metadata, pubkey_str: String, config: Option<StreamAccountConfig>, ) -> Result<RpcResponse<()>>
A cheat code to simulate account streaming.
When a transaction is processed, the accounts that are accessed are downloaded from the datasource and cached in the SVM.
With this method, you can simulate the streaming of accounts by providing a pubkey. Read more
Sourcefn get_streamed_accounts(
&self,
meta: Self::Metadata,
) -> Result<RpcResponse<GetStreamedAccountsResponse>>
fn get_streamed_accounts( &self, meta: Self::Metadata, ) -> Result<RpcResponse<GetStreamedAccountsResponse>>
A cheat code to retrieve the streamed accounts.
When a transaction is processed, the accounts that are accessed are downloaded from the datasource and cached in the SVM.
With this method, you can simulate the streaming of accounts by providing a pubkey. Read more
Sourcefn get_surfnet_info(
&self,
meta: Self::Metadata,
) -> Result<RpcResponse<GetSurfnetInfoResponse>>
fn get_surfnet_info( &self, meta: Self::Metadata, ) -> Result<RpcResponse<GetSurfnetInfoResponse>>
A cheat code to get Surfnet network information. Read more
Sourcefn write_program(
&self,
meta: Self::Metadata,
program_id_str: String,
data_hex: String,
offset: usize,
authority: Option<String>,
) -> BoxFuture<Result<RpcResponse<()>>>
fn write_program( &self, meta: Self::Metadata, program_id_str: String, data_hex: String, offset: usize, authority: Option<String>, ) -> BoxFuture<Result<RpcResponse<()>>>
A “cheat code” method for developers to write program data at a specified offset in Surfpool. Read more
Sourcefn export_snapshot(
&self,
meta: Self::Metadata,
config: Option<ExportSnapshotConfig>,
) -> Result<RpcResponse<BTreeMap<String, AccountSnapshot>>>
fn export_snapshot( &self, meta: Self::Metadata, config: Option<ExportSnapshotConfig>, ) -> Result<RpcResponse<BTreeMap<String, AccountSnapshot>>>
A cheat code to export a snapshot of all accounts in the Surfnet SVM. Read more
Sourcefn register_scenario(
&self,
meta: Self::Metadata,
scenario: Scenario,
slot: Option<Slot>,
) -> Result<RpcResponse<()>>
fn register_scenario( &self, meta: Self::Metadata, scenario: Scenario, slot: Option<Slot>, ) -> Result<RpcResponse<()>>
A cheat code to register a scenario with account overrides. Read more
Sourcefn to_delegate(self) -> IoDelegate<Self, Self::Metadata>
fn to_delegate(self) -> IoDelegate<Self, Self::Metadata>
Create an
IoDelegate, wiring rpc calls to the trait methods.Auto Trait Implementations
impl Freeze for SurfnetCheatcodesRpc
impl RefUnwindSafe for SurfnetCheatcodesRpc
impl Send for SurfnetCheatcodesRpc
impl Sync for SurfnetCheatcodesRpc
impl Unpin for SurfnetCheatcodesRpc
impl UnsafeUnpin for SurfnetCheatcodesRpc
impl UnwindSafe for SurfnetCheatcodesRpc