pub struct AccountUpdate {
pub lamports: Option<u64>,
pub data: Option<Vec<u8>>,
pub owner: Option<String>,
pub executable: Option<bool>,
pub rent_epoch: Option<Epoch>,
}Fields
lamports: Option<u64>providing this value sets the lamports in the account
data: Option<Vec<u8>>providing this value sets the data held in this account
owner: Option<String>providing this value sets the program that owns this account. If executable, the program that loads this account.
executable: Option<bool>providing this value sets whether this account’s data contains a loaded program (and is now read-only)
rent_epoch: Option<Epoch>providing this value sets the epoch at which this account will next owe rent
Implementations