pub struct SurfpoolSvmTricksRpc;Trait Implementations
Sourceimpl SvmTricksRpc for SurfpoolSvmTricksRpc
impl SvmTricksRpc for SurfpoolSvmTricksRpc
type Metadata = Option<RunloopContext>
Sourcefn set_account(
&self,
meta: Self::Metadata,
pubkey_str: String,
update: AccountUpdate,
) -> BoxFuture<Result<RpcResponse<()>>>
fn set_account( &self, meta: Self::Metadata, pubkey_str: String, update: AccountUpdate, ) -> BoxFuture<Result<RpcResponse<()>>>
A “cheat code” method for developers to set or update an account in Surfpool. Read more
Sourcefn set_token_account(
&self,
meta: Self::Metadata,
owner_str: String,
mint_str: String,
update: TokenAccountUpdate,
some_token_program_str: Option<String>,
) -> BoxFuture<Result<RpcResponse<()>>>
fn set_token_account( &self, meta: Self::Metadata, owner_str: String, mint_str: String, update: TokenAccountUpdate, some_token_program_str: Option<String>, ) -> BoxFuture<Result<RpcResponse<()>>>
A “cheat code” method for developers to set or update a token account in Surfpool. Read more
Sourcefn to_delegate(self) -> IoDelegate<Self, Self::Metadata>
fn to_delegate(self) -> IoDelegate<Self, Self::Metadata>
Create an
IoDelegate, wiring rpc calls to the trait methods.Auto Trait Implementations
impl Freeze for SurfpoolSvmTricksRpc
impl RefUnwindSafe for SurfpoolSvmTricksRpc
impl Send for SurfpoolSvmTricksRpc
impl Sync for SurfpoolSvmTricksRpc
impl Unpin for SurfpoolSvmTricksRpc
impl UnwindSafe for SurfpoolSvmTricksRpc