pub enum GetAccountResult {
None(Pubkey),
FoundAccount(Pubkey, Account, bool),
FoundProgramAccount((Pubkey, Account), (Pubkey, Option<Account>)),
FoundTokenAccount((Pubkey, Account), (Pubkey, Option<Account>)),
}Expand description
Represents the result of a get_account operation.
Variants
None(Pubkey)
Represents that the account was not found.
FoundAccount(Pubkey, Account, bool)
Represents that the account was found.
The DoUpdateSvm flag indicates whether the SVM should be updated after this account is found.
This is useful for cases where the account was fetched from a remote source and needs to be
updated in the SVM to reflect the latest state. However, when the account is found locally,
it likely does not need to be updated in the SVM.
FoundProgramAccount((Pubkey, Account), (Pubkey, Option<Account>))
FoundTokenAccount((Pubkey, Account), (Pubkey, Option<Account>))
Implementations
Sourceimpl GetAccountResult
impl GetAccountResult
pub fn expected_data(&self) -> &Vec<u8> ⓘ
pub fn apply_update<T>(&mut self, update: T) -> RpcError<()>
pub fn map_account(self) -> SurfpoolResult<Account>
pub fn map_account_with_token_data( self, ) -> Option<((Pubkey, Account), Option<(Pubkey, Option<Account>)>)>
pub const fn is_none(&self) -> bool
pub const fn requires_update(&self) -> bool