Module remote

Module remote 

Structs

SurfnetRemoteClient

Traits

SomeRemoteCtx

Functions

handle_remote_rpc
Handles remote RPC calls, returning a RemoteRpcResult indicating whether the method was supported. If the method is not supported, it returns RemoteRpcResult::MethodNotSupported. If the method is supported, it returns RemoteRpcResult::Ok(T). If the method is supported but returns an error, it returns Err(E).