pub struct SurfpoolFullRpc;Trait Implementations
Sourceimpl Clone for SurfpoolFullRpc
impl Clone for SurfpoolFullRpc
Sourcefn clone(&self) -> SurfpoolFullRpc
fn clone(&self) -> SurfpoolFullRpc
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Full for SurfpoolFullRpc
impl Full for SurfpoolFullRpc
type Metadata = Option<RunloopContext>
Sourcefn get_inflation_reward(
&self,
_meta: Self::Metadata,
_address_strs: Vec<String>,
_config: Option<RpcEpochConfig>,
) -> BoxFuture<Result<Vec<Option<RpcInflationReward>>>>
fn get_inflation_reward( &self, _meta: Self::Metadata, _address_strs: Vec<String>, _config: Option<RpcEpochConfig>, ) -> BoxFuture<Result<Vec<Option<RpcInflationReward>>>>
Retrieves inflation rewards for a list of addresses over a specified epoch or context. Read more
Sourcefn get_cluster_nodes(
&self,
_meta: Self::Metadata,
) -> Result<Vec<RpcContactInfo>>
fn get_cluster_nodes( &self, _meta: Self::Metadata, ) -> Result<Vec<RpcContactInfo>>
Retrieves the list of cluster nodes and their contact information. Read more
Sourcefn get_recent_performance_samples(
&self,
meta: Self::Metadata,
limit: Option<usize>,
) -> Result<Vec<RpcPerfSample>>
fn get_recent_performance_samples( &self, meta: Self::Metadata, limit: Option<usize>, ) -> Result<Vec<RpcPerfSample>>
Retrieves recent performance samples of the Solana network. Read more
Sourcefn get_signature_statuses(
&self,
meta: Self::Metadata,
signature_strs: Vec<String>,
_config: Option<RpcSignatureStatusConfig>,
) -> BoxFuture<Result<RpcResponse<Vec<Option<TransactionStatus>>>>>
fn get_signature_statuses( &self, meta: Self::Metadata, signature_strs: Vec<String>, _config: Option<RpcSignatureStatusConfig>, ) -> BoxFuture<Result<RpcResponse<Vec<Option<TransactionStatus>>>>>
Retrieves the status of multiple transactions given their signatures. Read more
Sourcefn get_max_retransmit_slot(&self, _meta: Self::Metadata) -> Result<Slot>
fn get_max_retransmit_slot(&self, _meta: Self::Metadata) -> Result<Slot>
Retrieves the maximum slot number for which data may be retransmitted. Read more
Sourcefn get_max_shred_insert_slot(&self, _meta: Self::Metadata) -> Result<Slot>
fn get_max_shred_insert_slot(&self, _meta: Self::Metadata) -> Result<Slot>
Retrieves the maximum slot number for which shreds may be inserted into the ledger. Read more
Sourcefn request_airdrop(
&self,
meta: Self::Metadata,
pubkey_str: String,
lamports: u64,
_config: Option<RpcRequestAirdropConfig>,
) -> Result<String>
fn request_airdrop( &self, meta: Self::Metadata, pubkey_str: String, lamports: u64, _config: Option<RpcRequestAirdropConfig>, ) -> Result<String>
Requests an airdrop of lamports to the specified public key. Read more
Sourcefn send_transaction(
&self,
meta: Self::Metadata,
data: String,
config: Option<RpcSendTransactionConfig>,
) -> Result<String>
fn send_transaction( &self, meta: Self::Metadata, data: String, config: Option<RpcSendTransactionConfig>, ) -> Result<String>
Sends a transaction to the network. Read more
Sourcefn simulate_transaction(
&self,
meta: Self::Metadata,
data: String,
config: Option<RpcSimulateTransactionConfig>,
) -> BoxFuture<Result<RpcResponse<RpcSimulateTransactionResult>>>
fn simulate_transaction( &self, meta: Self::Metadata, data: String, config: Option<RpcSimulateTransactionConfig>, ) -> BoxFuture<Result<RpcResponse<RpcSimulateTransactionResult>>>
Simulates a transaction without sending it to the network. Read more
Sourcefn minimum_ledger_slot(&self, _meta: Self::Metadata) -> Result<Slot>
fn minimum_ledger_slot(&self, _meta: Self::Metadata) -> Result<Slot>
Retrieves the minimum ledger slot. Read more
Sourcefn get_block(
&self,
meta: Self::Metadata,
slot: Slot,
_config: Option<RpcEncodingConfigWrapper<RpcBlockConfig>>,
) -> BoxFuture<Result<Option<UiConfirmedBlock>>>
fn get_block( &self, meta: Self::Metadata, slot: Slot, _config: Option<RpcEncodingConfigWrapper<RpcBlockConfig>>, ) -> BoxFuture<Result<Option<UiConfirmedBlock>>>
Retrieves the details of a block in the blockchain. Read more
Sourcefn get_block_time(
&self,
_meta: Self::Metadata,
_slot: Slot,
) -> BoxFuture<Result<Option<UnixTimestamp>>>
fn get_block_time( &self, _meta: Self::Metadata, _slot: Slot, ) -> BoxFuture<Result<Option<UnixTimestamp>>>
Retrieves the timestamp for a block, given its slot number. Read more
Sourcefn get_blocks(
&self,
_meta: Self::Metadata,
_start_slot: Slot,
_wrapper: Option<RpcBlocksConfigWrapper>,
_config: Option<RpcContextConfig>,
) -> BoxFuture<Result<Vec<Slot>>>
fn get_blocks( &self, _meta: Self::Metadata, _start_slot: Slot, _wrapper: Option<RpcBlocksConfigWrapper>, _config: Option<RpcContextConfig>, ) -> BoxFuture<Result<Vec<Slot>>>
Retrieves a list of slot numbers starting from a given
start_slot. Read moreSourcefn get_blocks_with_limit(
&self,
_meta: Self::Metadata,
_start_slot: Slot,
_limit: usize,
_config: Option<RpcContextConfig>,
) -> BoxFuture<Result<Vec<Slot>>>
fn get_blocks_with_limit( &self, _meta: Self::Metadata, _start_slot: Slot, _limit: usize, _config: Option<RpcContextConfig>, ) -> BoxFuture<Result<Vec<Slot>>>
Retrieves a limited list of block slots starting from a given
start_slot. Read moreSourcefn get_transaction(
&self,
meta: Self::Metadata,
signature_str: String,
config: Option<RpcEncodingConfigWrapper<RpcTransactionConfig>>,
) -> BoxFuture<Result<Option<EncodedConfirmedTransactionWithStatusMeta>>>
fn get_transaction( &self, meta: Self::Metadata, signature_str: String, config: Option<RpcEncodingConfigWrapper<RpcTransactionConfig>>, ) -> BoxFuture<Result<Option<EncodedConfirmedTransactionWithStatusMeta>>>
Retrieves the details of a specific transaction by its signature. Read more
Sourcefn get_signatures_for_address(
&self,
_meta: Self::Metadata,
_address: String,
_config: Option<RpcSignaturesForAddressConfig>,
) -> BoxFuture<Result<Vec<RpcConfirmedTransactionStatusWithSignature>>>
fn get_signatures_for_address( &self, _meta: Self::Metadata, _address: String, _config: Option<RpcSignaturesForAddressConfig>, ) -> BoxFuture<Result<Vec<RpcConfirmedTransactionStatusWithSignature>>>
Returns confirmed transaction signatures for transactions involving an address. Read more
Sourcefn get_first_available_block(&self, meta: Self::Metadata) -> Result<Slot>
fn get_first_available_block(&self, meta: Self::Metadata) -> Result<Slot>
Returns the slot of the lowest confirmed block that has not been purged from the ledger. Read more
Sourcefn get_latest_blockhash(
&self,
meta: Self::Metadata,
_config: Option<RpcContextConfig>,
) -> Result<RpcResponse<RpcBlockhash>>
fn get_latest_blockhash( &self, meta: Self::Metadata, _config: Option<RpcContextConfig>, ) -> Result<RpcResponse<RpcBlockhash>>
Returns the latest blockhash and associated metadata needed to sign and send a transaction. Read more
Sourcefn is_blockhash_valid(
&self,
meta: Self::Metadata,
_blockhash: String,
_config: Option<RpcContextConfig>,
) -> Result<RpcResponse<bool>>
fn is_blockhash_valid( &self, meta: Self::Metadata, _blockhash: String, _config: Option<RpcContextConfig>, ) -> Result<RpcResponse<bool>>
Checks if a given blockhash is still valid for transaction inclusion. Read more
Sourcefn get_fee_for_message(
&self,
meta: Self::Metadata,
encoded: String,
_config: Option<RpcContextConfig>,
) -> Result<RpcResponse<Option<u64>>>
fn get_fee_for_message( &self, meta: Self::Metadata, encoded: String, _config: Option<RpcContextConfig>, ) -> Result<RpcResponse<Option<u64>>>
Returns the estimated fee required to submit a given transaction message. Read more
Sourcefn get_stake_minimum_delegation(
&self,
_meta: Self::Metadata,
_config: Option<RpcContextConfig>,
) -> Result<RpcResponse<u64>>
fn get_stake_minimum_delegation( &self, _meta: Self::Metadata, _config: Option<RpcContextConfig>, ) -> Result<RpcResponse<u64>>
Returns the current minimum delegation amount required for a stake account. Read more
Sourcefn get_recent_prioritization_fees(
&self,
_meta: Self::Metadata,
_pubkey_strs: Option<Vec<String>>,
) -> Result<Vec<RpcPrioritizationFee>>
fn get_recent_prioritization_fees( &self, _meta: Self::Metadata, _pubkey_strs: Option<Vec<String>>, ) -> Result<Vec<RpcPrioritizationFee>>
Returns recent prioritization fees for one or more accounts. Read more
Sourcefn to_delegate(self) -> IoDelegate<Self, Self::Metadata>
fn to_delegate(self) -> IoDelegate<Self, Self::Metadata>
Create an
IoDelegate, wiring rpc calls to the trait methods.Auto Trait Implementations
impl Freeze for SurfpoolFullRpc
impl RefUnwindSafe for SurfpoolFullRpc
impl Send for SurfpoolFullRpc
impl Sync for SurfpoolFullRpc
impl Unpin for SurfpoolFullRpc
impl UnwindSafe for SurfpoolFullRpc