pub struct SurfpoolMinimalRpc;Trait Implementations
Sourceimpl Clone for SurfpoolMinimalRpc
impl Clone for SurfpoolMinimalRpc
Sourcefn clone(&self) -> SurfpoolMinimalRpc
fn clone(&self) -> SurfpoolMinimalRpc
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Minimal for SurfpoolMinimalRpc
impl Minimal for SurfpoolMinimalRpc
type Metadata = Option<RunloopContext>
Sourcefn get_balance(
&self,
meta: Self::Metadata,
pubkey_str: String,
_config: Option<RpcContextConfig>,
) -> BoxFuture<Result<RpcResponse<u64>>>
fn get_balance( &self, meta: Self::Metadata, pubkey_str: String, _config: Option<RpcContextConfig>, ) -> BoxFuture<Result<RpcResponse<u64>>>
Returns the balance (in lamports) of the account at the provided public key. Read more
Sourcefn get_epoch_info(
&self,
meta: Self::Metadata,
_config: Option<RpcContextConfig>,
) -> Result<EpochInfo>
fn get_epoch_info( &self, meta: Self::Metadata, _config: Option<RpcContextConfig>, ) -> Result<EpochInfo>
Returns information about the current epoch. Read more
Sourcefn get_genesis_hash(&self, _meta: Self::Metadata) -> Result<String>
fn get_genesis_hash(&self, _meta: Self::Metadata) -> Result<String>
Returns the genesis hash of the blockchain. Read more
Sourcefn get_health(&self, _meta: Self::Metadata) -> Result<String>
fn get_health(&self, _meta: Self::Metadata) -> Result<String>
Returns the health status of the blockchain node. Read more
Sourcefn get_identity(&self, _meta: Self::Metadata) -> Result<RpcIdentity>
fn get_identity(&self, _meta: Self::Metadata) -> Result<RpcIdentity>
Returns the identity (public key) of the node. Read more
Sourcefn get_slot(
&self,
meta: Self::Metadata,
_config: Option<RpcContextConfig>,
) -> Result<Slot>
fn get_slot( &self, meta: Self::Metadata, _config: Option<RpcContextConfig>, ) -> Result<Slot>
Returns the current slot of the ledger. Read more
Sourcefn get_block_height(
&self,
meta: Self::Metadata,
_config: Option<RpcContextConfig>,
) -> Result<u64>
fn get_block_height( &self, meta: Self::Metadata, _config: Option<RpcContextConfig>, ) -> Result<u64>
Returns the current block height. Read more
Sourcefn get_highest_snapshot_slot(
&self,
_meta: Self::Metadata,
) -> Result<RpcSnapshotSlotInfo>
fn get_highest_snapshot_slot( &self, _meta: Self::Metadata, ) -> Result<RpcSnapshotSlotInfo>
Returns information about the highest snapshot slot. Read more
Sourcefn get_transaction_count(
&self,
meta: Self::Metadata,
_config: Option<RpcContextConfig>,
) -> Result<u64>
fn get_transaction_count( &self, meta: Self::Metadata, _config: Option<RpcContextConfig>, ) -> Result<u64>
Returns the total number of transactions processed by the blockchain. Read more
Sourcefn get_version(&self, _: Self::Metadata) -> Result<SurfpoolRpcVersionInfo>
fn get_version(&self, _: Self::Metadata) -> Result<SurfpoolRpcVersionInfo>
Returns the current version of the server or application. Read more
Sourcefn get_vote_accounts(
&self,
_meta: Self::Metadata,
_config: Option<RpcGetVoteAccountsConfig>,
) -> Result<RpcVoteAccountStatus>
fn get_vote_accounts( &self, _meta: Self::Metadata, _config: Option<RpcGetVoteAccountsConfig>, ) -> Result<RpcVoteAccountStatus>
Returns vote account information. Read more
Sourcefn get_leader_schedule(
&self,
_meta: Self::Metadata,
_options: Option<RpcLeaderScheduleConfigWrapper>,
_config: Option<RpcLeaderScheduleConfig>,
) -> Result<Option<RpcLeaderSchedule>>
fn get_leader_schedule( &self, _meta: Self::Metadata, _options: Option<RpcLeaderScheduleConfigWrapper>, _config: Option<RpcLeaderScheduleConfig>, ) -> Result<Option<RpcLeaderSchedule>>
Returns the leader schedule for the given configuration or slot. Read more
Sourcefn to_delegate(self) -> IoDelegate<Self, Self::Metadata>
fn to_delegate(self) -> IoDelegate<Self, Self::Metadata>
Create an
IoDelegate, wiring rpc calls to the trait methods.Auto Trait Implementations
impl Freeze for SurfpoolMinimalRpc
impl RefUnwindSafe for SurfpoolMinimalRpc
impl Send for SurfpoolMinimalRpc
impl Sync for SurfpoolMinimalRpc
impl Unpin for SurfpoolMinimalRpc
impl UnwindSafe for SurfpoolMinimalRpc