pub struct SurfnetCheatcodesRpc;Trait Implementations
Sourceimpl Clone for SurfnetCheatcodesRpc
impl Clone for SurfnetCheatcodesRpc
Sourcefn clone(&self) -> SurfnetCheatcodesRpc
fn clone(&self) -> SurfnetCheatcodesRpc
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SvmTricksRpc for SurfnetCheatcodesRpc
impl SvmTricksRpc for SurfnetCheatcodesRpc
Sourcefn clone_program_account(
&self,
meta: Self::Metadata,
source_program_id: String,
destination_program_id: String,
) -> BoxFuture<Result<RpcResponse<()>>>
fn clone_program_account( &self, meta: Self::Metadata, source_program_id: String, destination_program_id: String, ) -> BoxFuture<Result<RpcResponse<()>>>
Clones a program account from one program ID to another. A program account contains a pointer to a program data account, which is a PDA derived from the program ID. So, when cloning a program account, we need to clone the program data account as well.
This method will:
- Get the program account for the source program ID.
- Get the program data account for the source program ID.
- Calculate the program data address for the destination program ID.
- Set the destination program account’s data to point to the calculated destination program address.
- Copy the source program data account to the destination program data account.
type Metadata = Option<RunloopContext>
Sourcefn set_account(
&self,
meta: Self::Metadata,
pubkey_str: String,
update: AccountUpdate,
) -> BoxFuture<Result<RpcResponse<()>>>
fn set_account( &self, meta: Self::Metadata, pubkey_str: String, update: AccountUpdate, ) -> BoxFuture<Result<RpcResponse<()>>>
A “cheat code” method for developers to set or update an account in Surfpool. Read more
Sourcefn set_token_account(
&self,
meta: Self::Metadata,
owner_str: String,
mint_str: String,
update: TokenAccountUpdate,
some_token_program_str: Option<String>,
) -> BoxFuture<Result<RpcResponse<()>>>
fn set_token_account( &self, meta: Self::Metadata, owner_str: String, mint_str: String, update: TokenAccountUpdate, some_token_program_str: Option<String>, ) -> BoxFuture<Result<RpcResponse<()>>>
A “cheat code” method for developers to set or update a token account in Surfpool. Read more
Sourcefn profile_transaction(
&self,
meta: Self::Metadata,
transaction_data_b64: String,
tag: Option<String>,
encoding: Option<UiAccountEncoding>,
) -> BoxFuture<Result<RpcResponse<ProfileResult>>>
fn profile_transaction( &self, meta: Self::Metadata, transaction_data_b64: String, tag: Option<String>, encoding: Option<UiAccountEncoding>, ) -> BoxFuture<Result<RpcResponse<ProfileResult>>>
Estimates the compute units that a given transaction will consume. Read more
Sourcefn get_profile_results_by_tag(
&self,
meta: Self::Metadata,
tag: String,
) -> BoxFuture<Result<RpcResponse<Option<Vec<ProfileResult>>>>>
fn get_profile_results_by_tag( &self, meta: Self::Metadata, tag: String, ) -> BoxFuture<Result<RpcResponse<Option<Vec<ProfileResult>>>>>
Retrieves all profiling results for a given tag. Read more
Sourcefn set_supply(
&self,
meta: Self::Metadata,
update: SupplyUpdate,
) -> BoxFuture<Result<RpcResponse<()>>>
fn set_supply( &self, meta: Self::Metadata, update: SupplyUpdate, ) -> BoxFuture<Result<RpcResponse<()>>>
A “cheat code” method for developers to set or update the network supply information in Surfpool. Read more
A cheat code to set the upgrade authority of a program’s ProgramData account. Read more
fn get_transaction_profile( &self, meta: Self::Metadata, signature_or_uuid: UuidOrSignature, ) -> BoxFuture<Result<RpcResponse<Option<ProfileResult>>>>
Sourcefn to_delegate(self) -> IoDelegate<Self, Self::Metadata>
fn to_delegate(self) -> IoDelegate<Self, Self::Metadata>
Create an
IoDelegate, wiring rpc calls to the trait methods.Auto Trait Implementations
impl Freeze for SurfnetCheatcodesRpc
impl RefUnwindSafe for SurfnetCheatcodesRpc
impl Send for SurfnetCheatcodesRpc
impl Sync for SurfnetCheatcodesRpc
impl Unpin for SurfnetCheatcodesRpc
impl UnwindSafe for SurfnetCheatcodesRpc